summaryrefslogtreecommitdiffstats
path: root/datarouter-prov/src
diff options
context:
space:
mode:
authorFiachra Corcoran <fiachra.corcoran@ericsson.com>2018-07-26 07:23:34 +0100
committerFiachra Corcoran <fiachra.corcoran@ericsson.com>2018-07-30 09:12:50 +0100
commitfa1da98c8618e2e51ae5bddd6eb28fc1fb407e52 (patch)
tree23e5d94aaa47cac66b63ab980e6a73521a8dcc52 /datarouter-prov/src
parent102790938e1d344121be0edda6f82b6f1d9530fb (diff)
Replacing att.com namespace
Issue-ID: DMAAP-52 Change-Id: Ia6d5c1725119b893c50fed13c2c2d6fd47f4f917 Signed-off-by: Fiachra Corcoran <fiachra.corcoran@ericsson.com>
Diffstat (limited to 'datarouter-prov/src')
-rw-r--r--datarouter-prov/src/main/java/org/onap/dmaap/datarouter/authz/impl/package.html10
-rw-r--r--datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/BaseServlet.java6
-rw-r--r--datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/InternalServlet.java6
-rw-r--r--datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/Main.java18
-rw-r--r--datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/SynchronizerTask.java4
-rw-r--r--datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/beans/IngressRoute.java2
-rw-r--r--datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/beans/Subscription.java2
-rw-r--r--datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/package.html20
-rw-r--r--datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/utils/DB.java16
-rw-r--r--datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/utils/DRRouteCLI.java4
-rw-r--r--datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/utils/LogfileLoader.java2
-rw-r--r--datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/utils/PurgeLogDirTask.java6
-rw-r--r--datarouter-prov/src/main/java/org/onap/dmaap/datarouter/reports/package.html12
-rw-r--r--datarouter-prov/src/main/resources/docker-compose/docker-compose.yml16
-rw-r--r--datarouter-prov/src/main/resources/docker-compose/prov_data/provserver.properties53
-rw-r--r--datarouter-prov/src/main/resources/docker/startup.sh3
-rw-r--r--datarouter-prov/src/main/resources/log4j.properties14
-rw-r--r--datarouter-prov/src/main/resources/logback.xml2
-rw-r--r--datarouter-prov/src/main/resources/misc/doaction19
-rw-r--r--datarouter-prov/src/main/resources/misc/dr-route30
-rw-r--r--datarouter-prov/src/main/resources/misc/drtrprov30
-rw-r--r--datarouter-prov/src/main/resources/misc/log4j.drroute.properties16
-rw-r--r--datarouter-prov/src/main/resources/misc/log4j.properties.tmpl38
-rw-r--r--datarouter-prov/src/main/resources/misc/provcmd29
-rw-r--r--datarouter-prov/src/main/resources/misc/runreports30
-rw-r--r--datarouter-prov/src/main/resources/provserver.properties40
26 files changed, 227 insertions, 201 deletions
diff --git a/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/authz/impl/package.html b/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/authz/impl/package.html
index fae27ee0..0d051db3 100644
--- a/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/authz/impl/package.html
+++ b/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/authz/impl/package.html
@@ -2,7 +2,7 @@
# ============LICENSE_START==================================================
# * org.onap.dmaap
# * ===========================================================================
-# * Copyright © 2017 AT&T Intellectual Property. All rights reserved.
+# * Copyright � 2017 AT&T Intellectual Property. All rights reserved.
# * ===========================================================================
# * Licensed under the Apache License, Version 2.0 (the "License");
# * you may not use this file except in compliance with the License.
@@ -27,7 +27,7 @@
<body>
<p>
This package provides an implementation of the authorization-related interfaces
-defined by the <code>com.att.research.datarouter.authz</code> package, intended for
+defined by the <code>org.onap.dmaap.datarouter.authz</code> package, intended for
use with the provisioning server for Data Router Release 1. In DR R1, we do not
have an external policy engine, so this implementation performs the authorization
locally.
@@ -35,7 +35,7 @@ locally.
<p>
In order to perform the authorization, this package needs access to provisioning data
about feeds and subscriptions. This package defines an interface
-(<code>com.att.research.datarouter.authz.impl.ProvDataProvider</code>) through which it
+(<code>org.onap.dmaap.datarouter.authz.impl.ProvDataProvider</code>) through which it
expects to get this data. The provisioning server code must provide an implementation
of this interface.
</p>
@@ -43,14 +43,14 @@ of this interface.
A software component that wishes to use this implementation must:
<ul>
<li>Provide an implementation of the
-<code>com.att.research.datarouter.authz.impl.ProvDataProvider</code>
+<code>org.onap.dmaap.datarouter.authz.impl.ProvDataProvider</code>
interface.
</li>
<li>
Create an instance of the <code>ProvDataProvider</code> implementation.
<li>
Create an instance of the
-<code>com.att.research.datarouter.authz.impl.ProvAuthorizer</code>
+<code>org.onap.dmaap.datarouter.authz.impl.ProvAuthorizer</code>
class defined in this package, passing it an instance of the <code>ProvDataProvider</code>
implementation.
</li>
diff --git a/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/BaseServlet.java b/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/BaseServlet.java
index 45d97485..fb13f5d6 100644
--- a/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/BaseServlet.java
+++ b/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/BaseServlet.java
@@ -484,11 +484,11 @@ public class BaseServlet extends HttpServlet implements ProvDataProvider {
private void checkHttpsRelaxation() {
if(mailSendFlag == false) {
Properties p = (new DB()).getProperties();
- intlogger.info("HTTPS relaxatio: "+p.get("com.att.research.datarouter.provserver.https.relaxation"));
+ intlogger.info("HTTPS relaxatio: "+p.get("org.onap.dmaap.datarouter.provserver.https.relaxation"));
- if(p.get("com.att.research.datarouter.provserver.https.relaxation").equals("true")) {
+ if(p.get("org.onap.dmaap.datarouter.provserver.https.relaxation").equals("true")) {
try {
- notifyPSTeam(p.get("com.att.research.datarouter.provserver.https.relax.notify").toString());
+ notifyPSTeam(p.get("org.onap.dmaap.datarouter.provserver.https.relax.notify").toString());
}
catch (Exception e) {
e.printStackTrace();
diff --git a/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/InternalServlet.java b/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/InternalServlet.java
index bec58ccd..14c960cc 100644
--- a/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/InternalServlet.java
+++ b/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/InternalServlet.java
@@ -256,7 +256,7 @@ public class InternalServlet extends ProxyServlet {
}
if (path.startsWith("/logs/")) {
Properties p = (new DB()).getProperties();
- String logdir = p.getProperty("com.att.research.datarouter.provserver.accesslog.dir");
+ String logdir = p.getProperty("org.onap.dmaap.datarouter.provserver.accesslog.dir");
String logfile = path.substring(6);
if (logdir != null && logfile != null && logfile.indexOf('/') < 0) {
File log = new File(logdir + "/" + logfile);
@@ -399,7 +399,7 @@ public class InternalServlet extends ProxyServlet {
eventlogger.info(elr);
return;
}
- String spooldir = (new DB()).getProperties().getProperty("com.att.research.datarouter.provserver.spooldir");
+ String spooldir = (new DB()).getProperties().getProperty("org.onap.dmaap.datarouter.provserver.spooldir");
String spoolname = String.format("%d-%d-", System.currentTimeMillis(), Thread.currentThread().getId());
synchronized (logseq) {
// perhaps unnecessary, but it helps make the name unique
@@ -487,7 +487,7 @@ public class InternalServlet extends ProxyServlet {
private JSONArray generateLogfileList() {
JSONArray ja = new JSONArray();
Properties p = (new DB()).getProperties();
- String s = p.getProperty("com.att.research.datarouter.provserver.accesslog.dir");
+ String s = p.getProperty("org.onap.dmaap.datarouter.provserver.accesslog.dir");
if (s != null) {
String[] dirs = s.split(",");
for (String dir : dirs) {
diff --git a/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/Main.java b/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/Main.java
index f5c93c79..70dbd446 100644
--- a/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/Main.java
+++ b/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/Main.java
@@ -82,11 +82,11 @@ import org.onap.dmaap.datarouter.provisioning.utils.ThrottleFilter;
public class Main {
/** The truststore to use if none is specified */
public static final String DEFAULT_TRUSTSTORE = "/opt/java/jdk/jdk180/jre/lib/security/cacerts";
- public static final String KEYSTORE_TYPE_PROPERTY = "com.att.research.datarouter.provserver.keystore.type";
- public static final String KEYSTORE_PATH_PROPERTY = "com.att.research.datarouter.provserver.keystore.path";
- public static final String KEYSTORE_PASSWORD_PROPERTY = "com.att.research.datarouter.provserver.keystore.password";
- public static final String TRUSTSTORE_PATH_PROPERTY = "com.att.research.datarouter.provserver.truststore.path";
- public static final String TRUSTSTORE_PASSWORD_PROPERTY = "com.att.research.datarouter.provserver.truststore.password";
+ public static final String KEYSTORE_TYPE_PROPERTY = "org.onap.dmaap.datarouter.provserver.keystore.type";
+ public static final String KEYSTORE_PATH_PROPERTY = "org.onap.dmaap.datarouter.provserver.keystore.path";
+ public static final String KEYSTORE_PASSWORD_PROPERTY = "org.onap.dmaap.datarouter.provserver.keystore.password";
+ public static final String TRUSTSTORE_PATH_PROPERTY = "org.onap.dmaap.datarouter.provserver.truststore.path";
+ public static final String TRUSTSTORE_PASSWORD_PROPERTY = "org.onap.dmaap.datarouter.provserver.truststore.password";
/** The one and only {@link Server} instance in this JVM */
private static Server server;
@@ -108,8 +108,8 @@ public class Main {
// Get properties
Properties p = (new DB()).getProperties();
- int http_port = Integer.parseInt(p.getProperty("com.att.research.datarouter.provserver.http.port", "8080"));
- int https_port = Integer.parseInt(p.getProperty("com.att.research.datarouter.provserver.https.port", "8443"));
+ int http_port = Integer.parseInt(p.getProperty("org.onap.dmaap.datarouter.provserver.http.port", "8080"));
+ int https_port = Integer.parseInt(p.getProperty("org.onap.dmaap.datarouter.provserver.https.port", "8443"));
// HTTP connector
SelectChannelConnector http = new SelectChannelConnector();
@@ -138,7 +138,7 @@ public class Main {
cf.setKeyStoreType(p.getProperty(KEYSTORE_TYPE_PROPERTY, "jks"));
cf.setKeyStorePath(p.getProperty(KEYSTORE_PATH_PROPERTY));
cf.setKeyStorePassword(p.getProperty(KEYSTORE_PASSWORD_PROPERTY));
- cf.setKeyManagerPassword(p.getProperty("com.att.research.datarouter.provserver.keymanager.password"));
+ cf.setKeyManagerPassword(p.getProperty("org.onap.dmaap.datarouter.provserver.keymanager.password"));
String ts = p.getProperty(TRUSTSTORE_PATH_PROPERTY);
if (ts != null && ts.length() > 0) {
System.out.println("@@ TS -> "+ts);
@@ -173,7 +173,7 @@ public class Main {
// Request log configuration
NCSARequestLog nrl = new NCSARequestLog();
- nrl.setFilename(p.getProperty("com.att.research.datarouter.provserver.accesslog.dir") + "/request.log.yyyy_mm_dd");
+ nrl.setFilename(p.getProperty("org.onap.dmaap.datarouter.provserver.accesslog.dir") + "/request.log.yyyy_mm_dd");
nrl.setFilenameDateFormat("yyyyMMdd");
nrl.setRetainDays(90);
nrl.setAppend(true);
diff --git a/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/SynchronizerTask.java b/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/SynchronizerTask.java
index a85bfc88..1e5751a3 100644
--- a/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/SynchronizerTask.java
+++ b/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/SynchronizerTask.java
@@ -130,7 +130,7 @@ public class SynchronizerTask extends TimerTask {
private SynchronizerTask() {
logger = Logger.getLogger("org.onap.dmaap.datarouter.provisioning.internal");
rolex = new Timer();
- spooldir = (new DB()).getProperties().getProperty("com.att.research.datarouter.provserver.spooldir");
+ spooldir = (new DB()).getProperties().getProperty("org.onap.dmaap.datarouter.provserver.spooldir");
state = UNKNOWN;
doFetch = true; // start off with a fetch
nextsynctime = 0;
@@ -172,7 +172,7 @@ public class SynchronizerTask extends TimerTask {
// Run once every 5 seconds to check DNS, etc.
long interval = 0;
try {
- String s = props.getProperty("com.att.research.datarouter.provserver.sync_interval", "5000");
+ String s = props.getProperty("org.onap.dmaap.datarouter.provserver.sync_interval", "5000");
interval = Long.parseLong(s);
} catch (NumberFormatException e) {
interval = 5000L;
diff --git a/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/beans/IngressRoute.java b/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/beans/IngressRoute.java
index 056c7695..39d859dc 100644
--- a/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/beans/IngressRoute.java
+++ b/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/beans/IngressRoute.java
@@ -302,7 +302,7 @@ public class IngressRoute extends NodeClass implements Comparable<IngressRoute>
/**
* Compare IP addresses as byte arrays to a subnet specified as a CIDR.
- * Taken from com.att.research.datarouter.node.SubnetMatcher and modified somewhat.
+ * Taken from org.onap.dmaap.datarouter.node.SubnetMatcher and modified somewhat.
*/
public class SubnetMatcher {
private byte[] sn;
diff --git a/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/beans/Subscription.java b/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/beans/Subscription.java
index 7e9f2ca8..4084f744 100644
--- a/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/beans/Subscription.java
+++ b/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/beans/Subscription.java
@@ -213,7 +213,7 @@ public class Subscription extends Syncable {
//Data Router Subscriber HTTPS Relaxation feature USERSTORYID:US674047.
Properties p = (new DB()).getProperties();
- if(p.get("com.att.research.datarouter.provserver.https.relaxation").toString().equals("false") && !jo.has("sync")) {
+ if(p.get("org.onap.dmaap.datarouter.provserver.https.relaxation").toString().equals("false") && !jo.has("sync")) {
if (!url.startsWith("https://"))
throw new InvalidObjectException("delivery URL is not HTTPS");
}
diff --git a/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/package.html b/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/package.html
index 7b009312..113b1cc4 100644
--- a/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/package.html
+++ b/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/package.html
@@ -2,7 +2,7 @@
# ============LICENSE_START==================================================
# * org.onap.dmaap
# * ===========================================================================
-# * Copyright © 2017 AT&T Intellectual Property. All rights reserved.
+# * Copyright � 2017 AT&T Intellectual Property. All rights reserved.
# * ===========================================================================
# * Licensed under the Apache License, Version 2.0 (the "License");
# * you may not use this file except in compliance with the License.
@@ -39,7 +39,7 @@ URLs are from the document <b>URLs for DR Release 1</b> <i>Version 1.2</i>.
<tr>
<td class="colFirst" class="colOne">/</td>
<td class="colOne" class="colOne">&lt;drFeedsUrl&gt;</td>
- <td class="colLast" class="colOne">{@link com.att.research.datarouter.provisioning.DRFeedsServlet}</td>
+ <td class="colLast" class="colOne">{@link org.onap.dmaap.datarouter.provisioning.DRFeedsServlet}</td>
<td class="colLast" class="colOne" style="background-color: pink">DELETE</td>
<td class="colLast" class="colOne" style="background-color: lightgreen">GET</td>
<td class="colLast" class="colOne" style="background-color: lightgreen">POST</td>
@@ -48,7 +48,7 @@ URLs are from the document <b>URLs for DR Release 1</b> <i>Version 1.2</i>.
<tr class="altColor">
<td class="colFirst" class="colOne">/feed/feedid</td>
<td class="colOne" class="colOne">&lt;feedUrl&gt;</td>
- <td class="colLast" class="colOne">{@link com.att.research.datarouter.provisioning.FeedServlet}</td>
+ <td class="colLast" class="colOne">{@link org.onap.dmaap.datarouter.provisioning.FeedServlet}</td>
<td class="colLast" style="background-color: lightgreen">DELETE</td>
<td class="colLast" style="background-color: lightgreen">GET</td>
<td class="colLast" style="background-color: pink">POST</td>
@@ -57,7 +57,7 @@ URLs are from the document <b>URLs for DR Release 1</b> <i>Version 1.2</i>.
<tr>
<td class="colFirst">/publish/feedid</td>
<td class="colOne">&lt;publishUrl&gt;</td>
- <td class="colLast">{@link com.att.research.datarouter.provisioning.PublishServlet}</td>
+ <td class="colLast">{@link org.onap.dmaap.datarouter.provisioning.PublishServlet}</td>
<td class="colLast" style="background-color: lightgreen">DELETE</td>
<td class="colLast" style="background-color: lightgreen">GET</td>
<td class="colLast" style="background-color: lightgreen">POST</td>
@@ -66,7 +66,7 @@ URLs are from the document <b>URLs for DR Release 1</b> <i>Version 1.2</i>.
<tr class="altColor">
<td class="colFirst">/subscribe/feedid</td>
<td class="colOne">&lt;subscribeUrl&gt;</td>
- <td class="colLast">{@link com.att.research.datarouter.provisioning.SubscribeServlet}</td>
+ <td class="colLast">{@link org.onap.dmaap.datarouter.provisioning.SubscribeServlet}</td>
<td class="colLast" style="background-color: pink">DELETE</td>
<td class="colLast" style="background-color: lightgreen">GET</td>
<td class="colLast" style="background-color: lightgreen">POST</td>
@@ -75,7 +75,7 @@ URLs are from the document <b>URLs for DR Release 1</b> <i>Version 1.2</i>.
<tr>
<td class="colFirst">/feedlog/feedid</td>
<td class="colOne">&lt;feedLogUrl&gt;</td>
- <td class="colLast">{@link com.att.research.datarouter.provisioning.FeedLogServlet}</td>
+ <td class="colLast">{@link org.onap.dmaap.datarouter.provisioning.FeedLogServlet}</td>
<td class="colLast" style="background-color: pink">DELETE</td>
<td class="colLast" style="background-color: lightgreen">GET</td>
<td class="colLast" style="background-color: pink">POST</td>
@@ -84,7 +84,7 @@ URLs are from the document <b>URLs for DR Release 1</b> <i>Version 1.2</i>.
<tr class="altColor">
<td class="colFirst">/subs/subid</td>
<td class="colOne">&lt;subscriptionUrl&gt;</td>
- <td class="colLast">{@link com.att.research.datarouter.provisioning.SubscriptionServlet}</td>
+ <td class="colLast">{@link org.onap.dmaap.datarouter.provisioning.SubscriptionServlet}</td>
<td class="colLast" style="background-color: lightgreen">DELETE</td>
<td class="colLast" style="background-color: lightgreen">GET</td>
<td class="colLast" style="background-color: lightgreen">POST</td>
@@ -93,7 +93,7 @@ URLs are from the document <b>URLs for DR Release 1</b> <i>Version 1.2</i>.
<tr>
<td class="colFirst">/sublog/subid</td>
<td class="colOne">&lt;subLogUrl&gt;</td>
- <td class="colLast">{@link com.att.research.datarouter.provisioning.SubLogServlet}</td>
+ <td class="colLast">{@link org.onap.dmaap.datarouter.provisioning.SubLogServlet}</td>
<td class="colLast" style="background-color: pink">DELETE</td>
<td class="colLast" style="background-color: lightgreen">GET</td>
<td class="colLast" style="background-color: pink">POST</td>
@@ -102,7 +102,7 @@ URLs are from the document <b>URLs for DR Release 1</b> <i>Version 1.2</i>.
<tr class="altColor">
<td class="colFirst">/internal/*</td>
<td class="colOne">&lt;internalUrl&gt;</td>
- <td class="colLast">{@link com.att.research.datarouter.provisioning.InternalServlet}</td>
+ <td class="colLast">{@link org.onap.dmaap.datarouter.provisioning.InternalServlet}</td>
<td class="colLast" style="background-color: lightgreen">DELETE</td>
<td class="colLast" style="background-color: lightgreen">GET</td>
<td class="colLast" style="background-color: lightgreen">POST</td>
@@ -111,7 +111,7 @@ URLs are from the document <b>URLs for DR Release 1</b> <i>Version 1.2</i>.
<tr>
<td class="colFirst">/internal/route/*</td>
<td class="colOne">&lt;routeUrl&gt;</td>
- <td class="colLast">{@link com.att.research.datarouter.provisioning.RouteServlet}</td>
+ <td class="colLast">{@link org.onap.dmaap.datarouter.provisioning.RouteServlet}</td>
<td class="colLast" style="background-color: lightgreen">DELETE</td>
<td class="colLast" style="background-color: lightgreen">GET</td>
<td class="colLast" style="background-color: lightgreen">POST</td>
diff --git a/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/utils/DRRouteCLI.java b/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/utils/DRRouteCLI.java
index 4c98f8e0..a3f4b32c 100644
--- a/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/utils/DRRouteCLI.java
+++ b/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/utils/DRRouteCLI.java
@@ -113,8 +113,8 @@ public class DRRouteCLI {
this.httpclient = new DefaultHttpClient();
Properties p = (new DB()).getProperties();
- String truststore_file = p.getProperty("com.att.research.datarouter.provserver.truststore.path");
- String truststore_pw = p.getProperty("com.att.research.datarouter.provserver.truststore.password");
+ String truststore_file = p.getProperty("org.onap.dmaap.datarouter.provserver.truststore.path");
+ String truststore_pw = p.getProperty("org.onap.dmaap.datarouter.provserver.truststore.password");
KeyStore trustStore = KeyStore.getInstance(KeyStore.getDefaultType());
if (truststore_file == null || truststore_file.equals("")) {
diff --git a/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/utils/LogfileLoader.java b/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/utils/LogfileLoader.java
index b19bee10..830e21c9 100644
--- a/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/utils/LogfileLoader.java
+++ b/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/utils/LogfileLoader.java
@@ -107,7 +107,7 @@ public class LogfileLoader extends Thread {
private LogfileLoader() {
this.logger = Logger.getLogger("org.onap.dmaap.datarouter.provisioning.internal");
this.db = new DB();
- this.spooldir = db.getProperties().getProperty("com.att.research.datarouter.provserver.spooldir");
+ this.spooldir = db.getProperties().getProperty("org.onap.dmaap.datarouter.provserver.spooldir");
this.set_start = getIdRange();
this.set_end = set_start + SET_SIZE - 1;
this.seq_set = new RLEBitSet();
diff --git a/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/reports/package.html b/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/reports/package.html
index 2c2d26b3..88c3d5e0 100644
--- a/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/reports/package.html
+++ b/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/reports/package.html
@@ -2,7 +2,7 @@
# ============LICENSE_START==================================================
# * org.onap.dmaap
# * ===========================================================================
-# * Copyright © 2017 AT&T Intellectual Property. All rights reserved.
+# * Copyright � 2017 AT&T Intellectual Property. All rights reserved.
# * ===========================================================================
# * Licensed under the Apache License, Version 2.0 (the "License");
# * you may not use this file except in compliance with the License.
@@ -33,11 +33,11 @@ The classes in this package, and the reports they generate are:
</p>
<table>
<tr><th>Class</th><th>Report</th></tr>
-<tr><td>{@link com.att.research.datarouter.reports.DailyLatencyReport}</td><td>dailylatency.csv</td></tr>
-<tr><td>{@link com.att.research.datarouter.reports.FeedReport}</td><td>NOT CURRENTLY USED</td></tr>
-<tr><td>{@link com.att.research.datarouter.reports.LatencyReport}</td><td></td></tr>
-<tr><td>{@link com.att.research.datarouter.reports.SubscriberReport}</td><td>subscriber.csv</td></tr>
-<tr><td>{@link com.att.research.datarouter.reports.VolumeReport}</td><td>volumes.csv</td></tr>
+<tr><td>{@link org.onap.dmaap.datarouter.reports.DailyLatencyReport}</td><td>dailylatency.csv</td></tr>
+<tr><td>{@link org.onap.dmaap.datarouter.reports.FeedReport}</td><td>NOT CURRENTLY USED</td></tr>
+<tr><td>{@link org.onap.dmaap.datarouter.reports.LatencyReport}</td><td></td></tr>
+<tr><td>{@link org.onap.dmaap.datarouter.reports.SubscriberReport}</td><td>subscriber.csv</td></tr>
+<tr><td>{@link org.onap.dmaap.datarouter.reports.VolumeReport}</td><td>volumes.csv</td></tr>
</table>
</body>
</html>
diff --git a/datarouter-prov/src/main/resources/docker-compose/docker-compose.yml b/datarouter-prov/src/main/resources/docker-compose/docker-compose.yml
index 4e2a81a7..1c33e3b8 100644
--- a/datarouter-prov/src/main/resources/docker-compose/docker-compose.yml
+++ b/datarouter-prov/src/main/resources/docker-compose/docker-compose.yml
@@ -20,10 +20,10 @@
# * ECOMP is a trademark and service mark of AT&T Intellectual Property.
# *
#-------------------------------------------------------------------------------
-version: '2'
+version: '2.1'
services:
datarouter-prov:
- image: attos/datarouter-prov
+ image: onap/dmaap/datarouter-prov
container_name: datarouter-prov
hostname: prov.datarouternew.com
ports:
@@ -36,13 +36,13 @@ services:
# - ./prov_data/addFeed3.txt:/opt/app/datartr/addFeed3.txt
entrypoint: ["bash", "-c", "sleep 10; /bin/sh -c ./startup.sh"]
depends_on:
- - mysql_container
+ mysql_container:
+ condition: service_healthy
extra_hosts:
- "node.datarouternew.com:172.18.0.4"
-
datarouter-node:
- image: attos/datarouter-node
+ image: onap/dmaap/datarouter-node
container_name: datarouter-node
hostname: node.datarouternew.com
ports:
@@ -60,10 +60,10 @@ services:
image: mysql/mysql-server:5.6
container_name: mysql
ports:
- - "3306:3306"
+ - "3306:3306"
environment:
MYSQL_ROOT_PASSWORD: att2017
volumes:
- - ./database:/tmp/database
- - ./database:/docker-entrypoint-initdb.d
+ - ./database:/tmp/database
+ - ./database:/docker-entrypoint-initdb.d
diff --git a/datarouter-prov/src/main/resources/docker-compose/prov_data/provserver.properties b/datarouter-prov/src/main/resources/docker-compose/prov_data/provserver.properties
index 6a03cbd1..b722a640 100644
--- a/datarouter-prov/src/main/resources/docker-compose/prov_data/provserver.properties
+++ b/datarouter-prov/src/main/resources/docker-compose/prov_data/provserver.properties
@@ -2,7 +2,7 @@
# ============LICENSE_START==================================================
# * org.onap.dmaap
# * ===========================================================================
-# * Copyright © 2017 AT&T Intellectual Property. All rights reserved.
+# * Copyright � 2017 AT&T Intellectual Property. All rights reserved.
# * ===========================================================================
# * Licensed under the Apache License, Version 2.0 (the "License");
# * you may not use this file except in compliance with the License.
@@ -20,40 +20,29 @@
# * ECOMP is a trademark and service mark of AT&T Intellectual Property.
# *
#-------------------------------------------------------------------------------
-#
-# AT&T - PROPRIETARY
-# THIS FILE CONTAINS PROPRIETARY INFORMATION OF
-# AT&T AND IS NOT TO BE DISCLOSED OR USED EXCEPT IN
-# ACCORDANCE WITH APPLICABLE AGREEMENTS.
-#
-# Copyright (c) 2013 AT&T Knowledge Ventures
-# Unpublished and Not for Publication
-# All Rights Reserved
-#
-# CVS: $Id: provserver.properties,v 1.7 2013/05/29 14:44:36 eby Exp $
-#
+
#Jetty Server properties
-com.att.research.datarouter.provserver.http.port = 8080
-com.att.research.datarouter.provserver.https.port = 8443
-com.att.research.datarouter.provserver.https.relaxation = true
-com.att.research.datarouter.provserver.keymanager.password = changeit
-com.att.research.datarouter.provserver.keystore.type = jks
-com.att.research.datarouter.provserver.keystore.path = /opt/app/datartr/self_signed/keystore.jks
+org.onap.dmaap.datarouter.provserver.http.port = 8080
+org.onap.dmaap.datarouter.provserver.https.port = 8443
+org.onap.dmaap.datarouter.provserver.https.relaxation = false
+org.onap.dmaap.datarouter.provserver.keymanager.password = changeit
+org.onap.dmaap.datarouter.provserver.keystore.type = jks
+org.onap.dmaap.datarouter.provserver.keystore.path = /opt/app/datartr/self_signed/keystore.jks
-com.att.research.datarouter.provserver.keystore.password = changeit
-#com.att.research.datarouter.provserver.truststore.path = /home/eby/dr2/misc/cacerts+1
-#com.att.research.datarouter.provserver.truststore.path = /usr/lib/jvm/java-8-oracle/jre/lib/security/cacerts
-com.att.research.datarouter.provserver.truststore.path = /opt/app/datartr/self_signed/cacerts.jks
+org.onap.dmaap.datarouter.provserver.keystore.password = changeit
+#org.onap.dmaap.datarouter.provserver.truststore.path = /home/eby/dr2/misc/cacerts+1
+#org.onap.dmaap.datarouter.provserver.truststore.path = /usr/lib/jvm/java-8-oracle/jre/lib/security/cacerts
+org.onap.dmaap.datarouter.provserver.truststore.path = /opt/app/datartr/self_signed/cacerts.jks
-com.att.research.datarouter.provserver.truststore.password = changeit
-com.att.research.datarouter.provserver.accesslog.dir = /opt/app/datartr/logs
-com.att.research.datarouter.provserver.spooldir = /opt/app/datartr/spool
-#com.att.research.datarouter.provserver.dbscripts = /home/eby/dr2/cvs/datarouter/prov/misc/
-com.att.research.datarouter.provserver.logretention = 30
+org.onap.dmaap.datarouter.provserver.truststore.password = changeit
+org.onap.dmaap.datarouter.provserver.accesslog.dir = /opt/app/datartr/logs
+org.onap.dmaap.datarouter.provserver.spooldir = /opt/app/datartr/spool
+#org.onap.dmaap.datarouter.provserver.dbscripts = /home/eby/dr2/cvs/datarouter/prov/misc/
+org.onap.dmaap.datarouter.provserver.logretention = 30
# Database access
-com.att.research.datarouter.db.driver = com.mysql.jdbc.Driver
-com.att.research.datarouter.db.url = jdbc:mysql://172.18.0.2:3306/datarouter
-com.att.research.datarouter.db.login = datarouter
-com.att.research.datarouter.db.password = datarouter
+org.onap.dmaap.datarouter.db.driver = com.mysql.jdbc.Driver
+org.onap.dmaap.datarouter.db.url = jdbc:mysql://172.18.0.2:3306/datarouter
+org.onap.dmaap.datarouter.db.login = datarouter
+org.onap.dmaap.datarouter.db.password = datarouter
diff --git a/datarouter-prov/src/main/resources/docker/startup.sh b/datarouter-prov/src/main/resources/docker/startup.sh
index 191a8049..e964f66e 100644
--- a/datarouter-prov/src/main/resources/docker/startup.sh
+++ b/datarouter-prov/src/main/resources/docker/startup.sh
@@ -1,3 +1,4 @@
+#!/bin/bash
LIB=/opt/app/datartr/lib
ETC=/opt/app/datartr/etc
echo "this is LIB" $LIB
@@ -8,7 +9,7 @@ CLASSPATH=$ETC
for FILE in `find $LIB -name *.jar`; do
CLASSPATH=$CLASSPATH:$FILE
done
-java -classpath $CLASSPATH com.att.research.datarouter.provisioning.Main
+java -classpath $CLASSPATH org.onap.dmaap.datarouter.provisioning.Main
runner_file="$LIB/datarouter-prov-jar-with-dependencies.jar"
echo "Starting using" $runner_file
diff --git a/datarouter-prov/src/main/resources/log4j.properties b/datarouter-prov/src/main/resources/log4j.properties
index bb4eaa0c..15ba888b 100644
--- a/datarouter-prov/src/main/resources/log4j.properties
+++ b/datarouter-prov/src/main/resources/log4j.properties
@@ -2,7 +2,7 @@
# ============LICENSE_START==================================================
# * org.onap.dmaap
# * ===========================================================================
-# * Copyright © 2017 AT&T Intellectual Property. All rights reserved.
+# * Copyright � 2017 AT&T Intellectual Property. All rights reserved.
# * ===========================================================================
# * Licensed under the Apache License, Version 2.0 (the "License");
# * you may not use this file except in compliance with the License.
@@ -31,8 +31,8 @@ log4j.appender.stdout.layout.ConversionPattern=%d %5p [%t] - %m%n
#
# Logger used for provisioning events
#
-log4j.logger.com.att.research.datarouter.provisioning.events=info, eventlog
-log4j.additivity.com.att.research.datarouter.provisioning.events=false
+log4j.logger.org.onap.dmaap.datarouter.provisioning.events=info, eventlog
+log4j.additivity.org.onap.dmaap.datarouter.provisioning.events=false
log4j.appender.eventlog=org.apache.log4j.DailyRollingFileAppender
log4j.appender.eventlog.file=/root/dr2/logs/provevent.log
@@ -44,8 +44,8 @@ log4j.appender.eventlog.layout.ConversionPattern=%d %-5p [%t] - %m%n
#
# Logger used for internal provisioning server events
#
-log4j.logger.com.att.research.datarouter.provisioning.internal=debug, intlog
-log4j.additivity.com.att.research.datarouter.provisioning.internal=false
+log4j.logger.org.onap.dmaap.datarouter.provisioning.internal=debug, intlog
+log4j.additivity.org.onap.dmaap.datarouter.provisioning.internal=false
log4j.appender.intlog=org.apache.log4j.DailyRollingFileAppender
log4j.appender.intlog.file=/root/dr2/logs/provint.log
@@ -57,8 +57,8 @@ log4j.appender.intlog.layout.ConversionPattern=%d %-5p [%t] - %m%n
#
# Logger used for policy engine
#
-log4j.logger.com.att.research.datarouter.authz.impl.ProvAuthorizer=debug, pelog
-log4j.additivity.com.att.research.datarouter.authz.impl.ProvAuthorizer=false
+log4j.logger.org.onap.dmaap.datarouter.authz.impl.ProvAuthorizer=debug, pelog
+log4j.additivity.org.onap.dmaap.datarouter.authz.impl.ProvAuthorizer=false
log4j.appender.pelog=org.apache.log4j.DailyRollingFileAppender
log4j.appender.pelog.file=/root/dr2/logs/policyengine.log
diff --git a/datarouter-prov/src/main/resources/logback.xml b/datarouter-prov/src/main/resources/logback.xml
index 7d73e0de..a9655154 100644
--- a/datarouter-prov/src/main/resources/logback.xml
+++ b/datarouter-prov/src/main/resources/logback.xml
@@ -301,7 +301,7 @@
<appender name="jettylog"
class="ch.qos.logback.core.rolling.RollingFileAppender">
<file>${logDirectory}/${jettyLogName}.log</file>
- <filter class="com.att.research.datarouter.provisioning.eelf.JettyFilter" />
+ <filter class="org.onap.dmaap.datarouter.provisioning.eelf.JettyFilter" />
<rollingPolicy
class="ch.qos.logback.core.rolling.FixedWindowRollingPolicy">
<fileNamePattern>${logDirectory}/${jettyLogName}.%i.log.zip
diff --git a/datarouter-prov/src/main/resources/misc/doaction b/datarouter-prov/src/main/resources/misc/doaction
index 43193324..8e719d4e 100644
--- a/datarouter-prov/src/main/resources/misc/doaction
+++ b/datarouter-prov/src/main/resources/misc/doaction
@@ -1,4 +1,23 @@
#!/bin/bash
+# ============LICENSE_START=======================================================
+# org.onap.dmaap
+# ================================================================================
+# Copyright © 2018 AT&T Intellectual Property. All rights reserved.
+# ================================================================================
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+# ============LICENSE_END=========================================================
+#
+# ECOMP is a trademark and service mark of AT&T Intellectual Property.
cd /opt/app/datartr/etc
for action in "$@"
diff --git a/datarouter-prov/src/main/resources/misc/dr-route b/datarouter-prov/src/main/resources/misc/dr-route
index 77c6c180..56d7766c 100644
--- a/datarouter-prov/src/main/resources/misc/dr-route
+++ b/datarouter-prov/src/main/resources/misc/dr-route
@@ -1,18 +1,24 @@
#!/bin/bash
+# ============LICENSE_START=======================================================
+# org.onap.dmaap
+# ================================================================================
+# Copyright © 2018 AT&T Intellectual Property. All rights reserved.
+# ================================================================================
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
#
-# AT&T - PROPRIETARY
-# THIS FILE CONTAINS PROPRIETARY INFORMATION OF
-# AT&T AND IS NOT TO BE DISCLOSED OR USED EXCEPT IN
-# ACCORDANCE WITH APPLICABLE AGREEMENTS.
+# http://www.apache.org/licenses/LICENSE-2.0
#
-# Copyright (c) 2013 AT&T Knowledge Ventures
-# Unpublished and Not for Publication
-# All Rights Reserved
-#
-# dr-route -- A script to interact with a provisioning server to manage the DR routing tables.
-#
-# $Id: dr-route,v 1.2 2013/11/06 16:23:54 eby Exp $
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+# ============LICENSE_END=========================================================
#
+# ECOMP is a trademark and service mark of AT&T Intellectual Property.
+
JAVA_HOME=/opt/java/jdk/jdk180
JAVA_OPTS="-Xms1G -Xmx1G"
@@ -23,4 +29,4 @@ export CLASSPATH JAVA_HOME JAVA_OPTS TZ PATH
$JAVA_HOME/bin/java \
-Dlog4j.configuration=file:///opt/app/datartr/etc/log4j.drroute.properties \
- com.att.research.datarouter.provisioning.utils.DRRouteCLI $*
+ org.onap.dmaap.datarouter.provisioning.utils.DRRouteCLI $*
diff --git a/datarouter-prov/src/main/resources/misc/drtrprov b/datarouter-prov/src/main/resources/misc/drtrprov
index c801ce04..2afb6ecb 100644
--- a/datarouter-prov/src/main/resources/misc/drtrprov
+++ b/datarouter-prov/src/main/resources/misc/drtrprov
@@ -1,18 +1,24 @@
#!/bin/bash
+# ============LICENSE_START=======================================================
+# org.onap.dmaap
+# ================================================================================
+# Copyright © 2018 AT&T Intellectual Property. All rights reserved.
+# ================================================================================
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
#
-# AT&T - PROPRIETARY
-# THIS FILE CONTAINS PROPRIETARY INFORMATION OF
-# AT&T AND IS NOT TO BE DISCLOSED OR USED EXCEPT IN
-# ACCORDANCE WITH APPLICABLE AGREEMENTS.
+# http://www.apache.org/licenses/LICENSE-2.0
#
-# Copyright (c) 2013 AT&T Knowledge Ventures
-# Unpublished and Not for Publication
-# All Rights Reserved
-#
-# This is the startup/shutdown script for the AT&T Data Router Provisioning Server.
-#
-# $Id: drtrprov,v 1.3 2013/10/29 16:57:57 eby Exp $
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+# ============LICENSE_END=========================================================
#
+# ECOMP is a trademark and service mark of AT&T Intellectual Property.
+
umask 0022
@@ -60,7 +66,7 @@ start() {
exit 0
fi
echo '0 1 * * * /opt/app/datartr/bin/runreports' | crontab
- nohup java $JAVA_OPTS com.att.research.datarouter.provisioning.Main </dev/null &
+ nohup java $JAVA_OPTS org.onap.dmaap.datarouter.provisioning.Main </dev/null &
sleep 5
PIDS=`pids`
if [ "$PIDS" = "" ]
diff --git a/datarouter-prov/src/main/resources/misc/log4j.drroute.properties b/datarouter-prov/src/main/resources/misc/log4j.drroute.properties
index 4ff4278c..57d93c8e 100644
--- a/datarouter-prov/src/main/resources/misc/log4j.drroute.properties
+++ b/datarouter-prov/src/main/resources/misc/log4j.drroute.properties
@@ -2,7 +2,7 @@
# ============LICENSE_START==================================================
# * org.onap.dmaap
# * ===========================================================================
-# * Copyright © 2017 AT&T Intellectual Property. All rights reserved.
+# * Copyright � 2017 AT&T Intellectual Property. All rights reserved.
# * ===========================================================================
# * Licensed under the Apache License, Version 2.0 (the "License");
# * you may not use this file except in compliance with the License.
@@ -19,20 +19,6 @@
# *
# * ECOMP is a trademark and service mark of AT&T Intellectual Property.
# *
-#-------------------------------------------------------------------------------
-#
-# AT&T - PROPRIETARY
-# THIS FILE CONTAINS PROPRIETARY INFORMATION OF
-# AT&T AND IS NOT TO BE DISCLOSED OR USED EXCEPT IN
-# ACCORDANCE WITH APPLICABLE AGREEMENTS.
-#
-# Copyright (c) 2013 AT&T Knowledge Ventures
-# Unpublished and Not for Publication
-# All Rights Reserved
-#
-# CVS: $Id: log4j.drroute.properties,v 1.1 2013/11/06 16:23:54 eby Exp $
-# This log4j properties file is used only by dr-route
-#
log4j.rootLogger=INFO, stdout
log4j.appender.stdout=org.apache.log4j.ConsoleAppender
diff --git a/datarouter-prov/src/main/resources/misc/log4j.properties.tmpl b/datarouter-prov/src/main/resources/misc/log4j.properties.tmpl
index ed1d7fab..304ee17c 100644
--- a/datarouter-prov/src/main/resources/misc/log4j.properties.tmpl
+++ b/datarouter-prov/src/main/resources/misc/log4j.properties.tmpl
@@ -1,24 +1,32 @@
cat <<!EOF
+# ============LICENSE_START=======================================================
+# org.onap.dmaap
+# ================================================================================
+# Copyright © 2018 AT&T Intellectual Property. All rights reserved.
+# ================================================================================
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
#
-# AT&T - PROPRIETARY
-# THIS FILE CONTAINS PROPRIETARY INFORMATION OF
-# AT&T AND IS NOT TO BE DISCLOSED OR USED EXCEPT IN
-# ACCORDANCE WITH APPLICABLE AGREEMENTS.
+# http://www.apache.org/licenses/LICENSE-2.0
#
-# Copyright (c) 2013 AT&T Knowledge Ventures
-# Unpublished and Not for Publication
-# All Rights Reserved
-#
-# CVS: $Id: log4j.properties.tmpl,v 1.4 2014/01/13 19:44:57 eby Exp $
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+# ============LICENSE_END=========================================================
#
+# ECOMP is a trademark and service mark of AT&T Intellectual Property.
+
log4j.rootLogger=info
#
# Logger used for provisioning events
#
-log4j.logger.com.att.research.datarouter.provisioning.events=info, eventlog
-log4j.additivity.com.att.research.datarouter.provisioning.events=false
+log4j.logger.org.onap.dmaap.datarouter.provisioning.events=info, eventlog
+log4j.additivity.org.onap.dmaap.datarouter.provisioning.events=false
log4j.appender.eventlog=org.apache.log4j.DailyRollingFileAppender
log4j.appender.eventlog.file=${DRTR_PROV_LOGS:-/opt/app/datartr/logs}/provevent.log
@@ -30,8 +38,8 @@ log4j.appender.eventlog.layout.ConversionPattern=%d %-5p [%t] - %m%n
#
# Logger used for internal provisioning server events
#
-log4j.logger.com.att.research.datarouter.provisioning.internal=debug, intlog
-log4j.additivity.com.att.research.datarouter.provisioning.internal=false
+log4j.logger.org.onap.dmaap.datarouter.provisioning.internal=debug, intlog
+log4j.additivity.org.onap.dmaap.datarouter.provisioning.internal=false
log4j.appender.intlog=org.apache.log4j.DailyRollingFileAppender
log4j.appender.intlog.file=${DRTR_PROV_LOGS:-/opt/app/datartr/logs}/provint.log
@@ -43,8 +51,8 @@ log4j.appender.intlog.layout.ConversionPattern=%d %-5p [%t] - %m%n
#
# Logger used for policy engine
#
-log4j.logger.com.att.research.datarouter.authz.impl.ProvAuthorizer=debug, pelog
-log4j.additivity.com.att.research.datarouter.authz.impl.ProvAuthorizer=false
+log4j.logger.org.onap.dmaap.datarouter.authz.impl.ProvAuthorizer=debug, pelog
+log4j.additivity.org.onap.dmaap.datarouter.authz.impl.ProvAuthorizer=false
log4j.appender.pelog=org.apache.log4j.DailyRollingFileAppender
log4j.appender.pelog.file=${DRTR_PROV_LOGS:-/opt/app/datartr/logs}/policyengine.log
diff --git a/datarouter-prov/src/main/resources/misc/provcmd b/datarouter-prov/src/main/resources/misc/provcmd
index 63efa543..b48084f1 100644
--- a/datarouter-prov/src/main/resources/misc/provcmd
+++ b/datarouter-prov/src/main/resources/misc/provcmd
@@ -1,19 +1,24 @@
#!/bin/bash
+# ============LICENSE_START=======================================================
+# org.onap.dmaap
+# ================================================================================
+# Copyright © 2018 AT&T Intellectual Property. All rights reserved.
+# ================================================================================
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
#
-# AT&T - PROPRIETARY
-# THIS FILE CONTAINS PROPRIETARY INFORMATION OF
-# AT&T AND IS NOT TO BE DISCLOSED OR USED EXCEPT IN
-# ACCORDANCE WITH APPLICABLE AGREEMENTS.
+# http://www.apache.org/licenses/LICENSE-2.0
#
-# Copyright (c) 2013 AT&T Knowledge Ventures
-# Unpublished and Not for Publication
-# All Rights Reserved
-#
-# provcmd -- A script to interact with a provisioning server to manage the provisioning parameters.
-# Set $VERBOSE to a non-empty string to see the curl commands as they are executed.
-#
-# $Id: provcmd,v 1.6 2014/03/31 13:23:33 eby Exp $
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+# ============LICENSE_END=========================================================
#
+# ECOMP is a trademark and service mark of AT&T Intellectual Property.
+
PATH=/opt/app/datartr/bin:/bin:/usr/bin:$PATH
PROVCMD="$0"
diff --git a/datarouter-prov/src/main/resources/misc/runreports b/datarouter-prov/src/main/resources/misc/runreports
index 009b7496..170d6efb 100644
--- a/datarouter-prov/src/main/resources/misc/runreports
+++ b/datarouter-prov/src/main/resources/misc/runreports
@@ -1,24 +1,30 @@
#!/bin/bash
+# ============LICENSE_START=======================================================
+# org.onap.dmaap
+# ================================================================================
+# Copyright © 2018 AT&T Intellectual Property. All rights reserved.
+# ================================================================================
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
#
-# AT&T - PROPRIETARY
-# THIS FILE CONTAINS PROPRIETARY INFORMATION OF
-# AT&T AND IS NOT TO BE DISCLOSED OR USED EXCEPT IN
-# ACCORDANCE WITH APPLICABLE AGREEMENTS.
+# http://www.apache.org/licenses/LICENSE-2.0
#
-# Copyright (c) 2013 AT&T Knowledge Ventures
-# Unpublished and Not for Publication
-# All Rights Reserved
-#
-# This script runs daily to generate reports files in the logs directory.
-#
-# $Id: runreports,v 1.2 2013/11/06 16:23:54 eby Exp $
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+# ============LICENSE_END=========================================================
#
+# ECOMP is a trademark and service mark of AT&T Intellectual Property.
+
umask 0022
JAVA_HOME=/opt/java/jdk/jdk180
JAVA_OPTS="-Xms1G -Xmx4G"
-JAVA_CLASS=com.att.research.datarouter.reports.Report
+JAVA_CLASS=org.onap.dmaap.datarouter.reports.Report
TZ=GMT0
PATH=$JAVA_HOME/bin:/bin:/usr/bin
CLASSPATH=`echo /opt/app/datartr/etc /opt/app/datartr/lib/*.jar | tr ' ' ':'`
diff --git a/datarouter-prov/src/main/resources/provserver.properties b/datarouter-prov/src/main/resources/provserver.properties
index af5073e5..b722a640 100644
--- a/datarouter-prov/src/main/resources/provserver.properties
+++ b/datarouter-prov/src/main/resources/provserver.properties
@@ -2,7 +2,7 @@
# ============LICENSE_START==================================================
# * org.onap.dmaap
# * ===========================================================================
-# * Copyright © 2017 AT&T Intellectual Property. All rights reserved.
+# * Copyright � 2017 AT&T Intellectual Property. All rights reserved.
# * ===========================================================================
# * Licensed under the Apache License, Version 2.0 (the "License");
# * you may not use this file except in compliance with the License.
@@ -23,26 +23,26 @@
#Jetty Server properties
-com.att.research.datarouter.provserver.http.port = 8080
-com.att.research.datarouter.provserver.https.port = 8443
-com.att.research.datarouter.provserver.https.relaxation = true
-com.att.research.datarouter.provserver.keymanager.password = changeit
-com.att.research.datarouter.provserver.keystore.type = jks
-com.att.research.datarouter.provserver.keystore.path = /opt/app/datartr/self_signed/keystore.jks
+org.onap.dmaap.datarouter.provserver.http.port = 8080
+org.onap.dmaap.datarouter.provserver.https.port = 8443
+org.onap.dmaap.datarouter.provserver.https.relaxation = false
+org.onap.dmaap.datarouter.provserver.keymanager.password = changeit
+org.onap.dmaap.datarouter.provserver.keystore.type = jks
+org.onap.dmaap.datarouter.provserver.keystore.path = /opt/app/datartr/self_signed/keystore.jks
-com.att.research.datarouter.provserver.keystore.password = changeit
-#com.att.research.datarouter.provserver.truststore.path = /home/eby/dr2/misc/cacerts+1
-#com.att.research.datarouter.provserver.truststore.path = /usr/lib/jvm/java-8-oracle/jre/lib/security/cacerts
-com.att.research.datarouter.provserver.truststore.path = /opt/app/datartr/self_signed/cacerts.jks
+org.onap.dmaap.datarouter.provserver.keystore.password = changeit
+#org.onap.dmaap.datarouter.provserver.truststore.path = /home/eby/dr2/misc/cacerts+1
+#org.onap.dmaap.datarouter.provserver.truststore.path = /usr/lib/jvm/java-8-oracle/jre/lib/security/cacerts
+org.onap.dmaap.datarouter.provserver.truststore.path = /opt/app/datartr/self_signed/cacerts.jks
-com.att.research.datarouter.provserver.truststore.password = changeit
-com.att.research.datarouter.provserver.accesslog.dir = /opt/app/datartr/logs
-com.att.research.datarouter.provserver.spooldir = /opt/app/datartr/spool
-#com.att.research.datarouter.provserver.dbscripts = /home/eby/dr2/cvs/datarouter/prov/misc/
-com.att.research.datarouter.provserver.logretention = 30
+org.onap.dmaap.datarouter.provserver.truststore.password = changeit
+org.onap.dmaap.datarouter.provserver.accesslog.dir = /opt/app/datartr/logs
+org.onap.dmaap.datarouter.provserver.spooldir = /opt/app/datartr/spool
+#org.onap.dmaap.datarouter.provserver.dbscripts = /home/eby/dr2/cvs/datarouter/prov/misc/
+org.onap.dmaap.datarouter.provserver.logretention = 30
# Database access
-com.att.research.datarouter.db.driver = com.mysql.jdbc.Driver
-com.att.research.datarouter.db.url = jdbc:mysql://172.18.0.2:3306/datarouter
-com.att.research.datarouter.db.login = datarouter
-com.att.research.datarouter.db.password = datarouter
+org.onap.dmaap.datarouter.db.driver = com.mysql.jdbc.Driver
+org.onap.dmaap.datarouter.db.url = jdbc:mysql://172.18.0.2:3306/datarouter
+org.onap.dmaap.datarouter.db.login = datarouter
+org.onap.dmaap.datarouter.db.password = datarouter
diff --git a/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/utils/DB.java b/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/utils/DB.java
index 1f558ec8..01605718 100644
--- a/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/utils/DB.java
+++ b/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/utils/DB.java
@@ -83,12 +83,12 @@ public class DB {
InputStream inStream = getClass().getClassLoader().getResourceAsStream(CONFIG_FILE);
try {
props.load(inStream);
- DB_DRIVER = (String) props.get("com.att.research.datarouter.db.driver");
- DB_URL = (String) props.get("com.att.research.datarouter.db.url");
- DB_LOGIN = (String) props.get("com.att.research.datarouter.db.login");
- DB_PASSWORD = (String) props.get("com.att.research.datarouter.db.password");
- HTTPS_PORT = (String) props.get("com.att.research.datarouter.provserver.https.port");
- HTTP_PORT = (String) props.get("com.att.research.datarouter.provserver.http.port");
+ DB_DRIVER = (String) props.get("org.onap.dmaap.datarouter.db.driver");
+ DB_URL = (String) props.get("org.onap.dmaap.datarouter.db.url");
+ DB_LOGIN = (String) props.get("org.onap.dmaap.datarouter.db.login");
+ DB_PASSWORD = (String) props.get("org.onap.dmaap.datarouter.db.password");
+ HTTPS_PORT = (String) props.get("org.onap.dmaap.datarouter.provserver.https.port");
+ HTTP_PORT = (String) props.get("org.onap.dmaap.datarouter.provserver.http.port");
Class.forName(DB_DRIVER);
} catch (IOException e) {
intlogger.fatal("PROV9003 Opening properties: "+e.getMessage());
@@ -671,13 +671,13 @@ public class DB {
}
/**
* Initialize the tables by running the initialization scripts located in the directory specified
* by the property <i>com.att.research.datarouter.provserver.dbscripts</i>. Scripts have names of
* the form mysql_init_NNNN.
* @param c a DB connection
* @param n the number of the mysql_init_NNNN script to run
*/
private void runInitScript(Connection c, int n) {
- String scriptdir = (String) props.get("com.att.research.datarouter.provserver.dbscripts");
+ String scriptdir = (String) props.get("org.onap.dmaap.datarouter.provserver.dbscripts");
StringBuilder sb = new StringBuilder();
try {
String scriptfile = String.format("%s/mysql_init_%04d", scriptdir, n);
@@ -671,13 +671,13 @@ public class DB {
/**
* Initialize the tables by running the initialization scripts located in the directory specified
- * by the property <i>com.att.research.datarouter.provserver.dbscripts</i>. Scripts have names of
+ * by the property <i>org.onap.dmaap.datarouter.provserver.dbscripts</i>. Scripts have names of
* the form mysql_init_NNNN.
* @param c a DB connection
diff --git a/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/utils/PurgeLogDirTask.java b/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/utils/PurgeLogDirTask.java
index 5a5d550f..8cfce5cf 100644
--- a/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/utils/PurgeLogDirTask.java
+++ b/datarouter-prov/src/main/java/org/onap/dmaap/datarouter/provisioning/utils/PurgeLogDirTask.java
@@ -30,7 +30,7 @@ import java.util.TimerTask;
/**
* This class provides a {@link TimerTask} that purges old logfiles
* (older than the number of days specified by the com.att.research.datarouter.provserver.logretention property).
* @author Robert Eby
* @version $Id: PurgeLogDirTask.java,v 1.2 2013/07/05 13:48:05 eby Exp $
*/
@@ -42,8 +42,8 @@ public class PurgeLogDirTask extends TimerTask {
public PurgeLogDirTask() {
Properties p = (new DB()).getProperties();
- logdir = p.getProperty("com.att.research.datarouter.provserver.accesslog.dir");
- String s = p.getProperty("com.att.research.datarouter.provserver.logretention", "30");
+ logdir = p.getProperty("org.onap.dmaap.datarouter.provserver.accesslog.dir");
+ String s = p.getProperty("org.onap.dmaap.datarouter.provserver.logretention", "30");
long n = 30;
try {
n = Long.parseLong(s);
@@ -30,7 +30,7 @@ import java.util.TimerTask;
/**
* This class provides a {@link TimerTask} that purges old logfiles
- * (older than the number of days specified by the com.att.research.datarouter.provserver.logretention property).
+ * (older than the number of days specified by the org.onap.dmaap.datarouter.provserver.logretention property).
* @author Robert Eby
* @version $Id: PurgeLogDirTask.java,v 1.2 2013/07/05 13:48:05 eby Exp $